locals {
  number_of_bokers = length(var.subnet_ids)*var.number_of_broker_nodes_per_subnet
}

resource "aws_msk_configuration" "cluster_configuration" {
  kafka_versions    = [var.kafka_version]
  name              = "${var.cluster_name}-configuration"
  server_properties = <<PROPERTIES
%{ for config in var.configuration_parameters }
${config}
%{ endfor }
PROPERTIES
}

resource "aws_msk_cluster" "msk_cluster" {
  cluster_name           = var.cluster_name
  kafka_version          = var.kafka_version
  number_of_broker_nodes = local.number_of_bokers

  broker_node_group_info {
    client_subnets  = var.subnet_ids
    ebs_volume_size = var.ebs_volume_size
    instance_type   = var.instance_type
    security_groups = var.security_group_ids
  }

  configuration_info {
    arn      = aws_msk_configuration.cluster_configuration.arn
    revision = aws_msk_configuration.cluster_configuration.latest_revision
  }

  client_authentication {
    unauthenticated = false
    sasl {
      iam = true
    }
  }

  encryption_info {
    encryption_at_rest_kms_key_arn = var.encryption_kms_key_arn
    encryption_in_transit {
      client_broker = "TLS"
      in_cluster    = true
    }
  }

  open_monitoring {
    prometheus {
      jmx_exporter {
        enabled_in_broker = false
      }
      node_exporter {
        enabled_in_broker = false
      }
    }
  }

  lifecycle {
    prevent_destroy = true
  }

  tags = var.tags
}

